/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.persistence.api;

/**
 * It defines a memory instance manager able to create memory instance since
 * an identifier.
 * The method releaseInstance permit to use a Pool of memory instance manager.
 *
 * @author S.Chassande-Barrioz, P.Dechamboux
 */
public interface MemoryInstanceManager {

	/**
	 * It creates an instance since an identifier
	 * @param oid is the identifier of the futur object
	 * @param context can be used by the naming to access to the support
	 * @return a memory instance
	 * @throws PersistenceException if an error occured during the instanciation
	 * of the memory instance.
	 */
	Object newInstance(Object oid,
					   ConnectionHolder context) throws PersistenceException;

	/**
	 * A persistence service can offer two different models of programmation
	 * concerning the persistent java object. The first solution is to share
	 * the persistent java object between transactions (in parallel). In this
	 * case the persistent object has several State, one for each transaction.
	 * The second solution is to have one persistent object for each
	 * transaction. In this case each persistent object have only one state,
	 * the one used in the transaction.
	 * The first strategy permits to use the same persistent object (same java
	 * reference) in several threads/transactions. In other hand the second
	 * strategy avoids to use the cache for keeping the java reference to the 
	 * persistent object if the caching strategy is no cache.  
	 * This methods indicates the strategy to follow for a persistent object or
	 * its identifier.
	 * @param o is a persistent object or its identifier
	 * @return true for the first strategy (share persistent object between 
	 * transaction), false for the second strategy (one persistent instance
	 * per transaction).
	 * @see State
	 */
	boolean isObjectSharing(Object o);
}
