/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.persistence.api;

import org.objectweb.perseus.cache.api.CacheManager;
import org.objectweb.perseus.concurrency.api.ConcurrencyManager;

/**
 * This interface defines the links needed by a PersistenceManager:
 * - a CacheManager
 * [ - a ConcurencyManager implementation ]
 * [ - another PersistentManager which has the role of ContextCopyManager]
 * This interface is a Binding Controller weither the Fractal terminology.
 *
 * @author Luciano Garcia-Banuelos (Luciano.Garcia@imag.fr)
 */
public interface PersistenceManagerBindingController {

	/**
	 * It assignes the CacheManager used by the PersistenceManager.
	 * @param cm is the cache.
	 */
	void setCacheManager(CacheManager cm);

	/**
	 * It retrieves the CacheManager used by the PersistenceManager.
	 */
	CacheManager getCacheManager();


	/**
	 * It assignes the context copy manager instance. A context copy manager
	 * implements the PersistentManager interface. In addition It is optional.
	 * @param pm is the context copy manager.
	 */
	void setContextCopyManager(PersistenceManager pm);

	/**
	 * It retrieves the ContextCopyManager used by the PersistenceManager.
	 */
	PersistenceManager getContextCopyManager();


	/**
	 * It assignes the ConcurrencyManager instance. It is optional.
	 * @param cm is the ConcurrencyManager instance.
	 */
	void setConcurrencyManager(ConcurrencyManager cm);

	/**
	 * It retrieves the ConcurrencyManager used by the PersistenceManager.
	 */
	ConcurrencyManager getConcurrencyManager();
}
