/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.persistence.api;

import org.objectweb.perseus.concurrency.api.ConcurrencyManager;

/**
 * It defines a persistence manager able to manage context transactional or not.
 *
 * @author Luciano Garcia-Banuelos (Luciano.Garcia@imag.fr)
 */
public interface TransactionalPersistenceManager 
    extends PersistenceManager, ConcurrencyManager.ResourceProvider {

	/**
	 * converts a context to a transaction
	 * @param context becomes transactional
	 * @throws PersistenceException if the context is already transactional.
	 */
	void begin(TransactionalWorkingSet context) throws PersistenceException;

	/**
     * Prepare the transactinal context.
     * @param context the
     * @return true if the transaction can be commit or false is the transaction
     * must be rolled back.
     * @throws PersistenceException if an error raised during the prepare
     * operation, or if the context is not a transactional context.
     */
    boolean prepare(TransactionalWorkingSet context) throws PersistenceException;

    /**
	 * commits a transactional context. The call to the prepare method is
     * required.
	 * @param context
	 * @throws PersistenceException if an error raised during the commit
	 * operation, or if the context is not a transactional context.
	 */
	void commit(TransactionalWorkingSet context) throws PersistenceException;

	/**
	 * rollbacks a transactional context. The call to the prepare method is
     * required.
	 * @param context
	 * @throws PersistenceException if an error raised during the rollback
	 * operation, or if the context is not a transactional context.
	 */
	void rollback(TransactionalWorkingSet context) throws PersistenceException;
}
